@@ -6,15 +6,15 @@ import sys
 
 sys.path.insert (1, '..')
 
-import SOAP
+from SOAPpy import *
 
-ident = '$Id: cardClient.py,v 1.1.1.1 2001/06/27 21:36:14 cullman Exp $'
+ident = '$Id: cardClient.py,v 1.3 2003/05/09 12:46:11 warnes Exp $'
 
 endpoint = "http://localhost:12027/xmethodsInterop"
 sa = "urn:soapinterop"
 ns = "http://soapinterop.org/"
 
-serv = SOAP.SOAPProxy(endpoint, namespace=ns, soapaction=sa)
+serv = SOAPProxy(endpoint, namespace=ns, soapaction=sa)
 try: hand =  serv.dealHand(NumberOfCards = 13, StringSeparator = '\n')
 except: print "no dealHand"; hand = 0
 try: sortedhand = serv.dealArrangedHand(NumberOfCards=13,StringSeparator='\n')
@@ -25,3 +25,4 @@ except: print "no card"; card = 0
 print "*****hand****\n",hand,"\n*********"
 print "******sortedhand*****\n",sortedhand,"\n*********"
 print "card:",card
+
